@@ -1,7 +1,7 @@
 // drumkv1_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@
 
 #define DRUMKV1_SUBTITLE    "an old-school drum-kit sampler."
 #define DRUMKV1_WEBSITE     "http://drumkv1.sourceforge.net"
-#define DRUMKV1_COPYRIGHT   "Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved."
+#define DRUMKV1_COPYRIGHT   "Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved."
 
 #define DRUMKV1_DOMAIN      "rncbc.org"
 
@@ -60,8 +60,9 @@ public:
 	QString sPresetDir;
 	QString sSampleDir;
 
-	// Dial knob behavior mode.
+	// Knob behavior modes.
 	int iKnobDialMode;
+	int iKnobEditMode;
 
 	// Special persistent options.
 	bool bControlsEnabled;
@@ -74,6 +75,9 @@ public:
 	// Custom widget style theme.
 	QString sCustomStyleTheme;
 
+	// Whether to display GM Standard drum-note/key names.
+	bool bUseGMDrumNames;
+
 	// Singleton instance accessor.
 	static drumkv1_config *getInstance();
 
@@ -122,3 +126,4 @@ private:
 #endif	// __drumkv1_config_h
 
 // end of drumkv1_config.h
+
