@@ -1,7 +1,7 @@
 // drumkv1_controls.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -234,7 +234,7 @@ public:
 			m_mask = new_size - 1;
 			m_events = new_events;
 			if (old_events)
-				delete old_events;
+				delete [] old_events;
 		}
 	}
 
@@ -560,7 +560,7 @@ private:
 #include <math.h>
 
 drumkv1_controls::drumkv1_controls ( drumkv1 *pDrumk )
-	: m_pImpl(new drumkv1_controls::Impl()), m_mode(0),
+	: m_pImpl(new drumkv1_controls::Impl()), m_enabled(false),
 		m_sched_in(pDrumk), m_sched_out(pDrumk),
 		m_timeout(0), m_timein(0)
 {
