@@ -35,7 +35,7 @@
 
 drumkv1_lv2ui::drumkv1_lv2ui ( drumkv1_lv2 *pSampl,
 	LV2UI_Controller controller, LV2UI_Write_Function write_function )
-	: drumkv1_ui(pSampl)
+	: drumkv1_ui(pSampl, true)
 {
 	m_controller = controller;
 	m_write_function = write_function;
