@@ -1,7 +1,7 @@
 // drumkv1_lv2ui.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -48,7 +48,7 @@ class drumkv1_lv2ui : public drumkv1_ui
 public:
 
 	// Constructor.
-	drumkv1_lv2ui(drumkv1_lv2 *pSynth,
+	drumkv1_lv2ui(drumkv1_lv2 *pSampl,
 		LV2UI_Controller controller, LV2UI_Write_Function write_function);
 
 	// Accessors.
