@@ -31,6 +31,8 @@
 #include "drumkv1_controls.h"
 #include "drumkv1_programs.h"
 
+#include "ui_drumkv1widget.h"
+
 #include <QMessageBox>
 #include <QDir>
 #include <QTimer>
@@ -45,7 +47,7 @@
 
 // Constructor.
 drumkv1widget::drumkv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
-	: QWidget(pParent, wflags)
+	: QWidget(pParent, wflags), p_ui(new Ui::drumkv1widget), m_ui(*p_ui)
 {
 	Q_INIT_RESOURCE(drumkv1);
 
@@ -519,6 +521,8 @@ drumkv1widget::~drumkv1widget (void)
 {
 	if (m_sched_notifier)
 		delete m_sched_notifier;
+
+	delete p_ui;
 }
 
 
@@ -913,7 +917,7 @@ void drumkv1widget::loadPreset ( const QString& sFilename )
 
 	drumkv1_ui *pDrumkUi = ui_instance();
 	if (pDrumkUi)
-		drumkv1_param::loadPreset(pDrumkUi->instance(), sFilename);
+		pDrumkUi->loadPreset(sFilename);
 
 	updateLoadPreset(QFileInfo(sFilename).completeBaseName());
 }
@@ -927,7 +931,7 @@ void drumkv1widget::savePreset ( const QString& sFilename )
 
 	drumkv1_ui *pDrumkUi = ui_instance();
 	if (pDrumkUi)
-		drumkv1_param::savePreset(pDrumkUi->instance(), sFilename);
+		pDrumkUi->savePreset(sFilename);
 
 	const QString& sPreset
 		= QFileInfo(sFilename).completeBaseName();
@@ -1020,8 +1024,8 @@ void drumkv1widget::loadSampleFile ( const QString& sFilename )
 // Sample updater (crude experimental stuff II).
 void drumkv1widget::updateSample ( drumkv1_sample *pSample, bool bDirty )
 {
-	m_ui.Gen1Sample->setSample(pSample);
 	m_ui.Gen1Sample->setSampleName(currentNoteName());
+	m_ui.Gen1Sample->setSample(pSample);
 
 	if (pSample && bDirty)
 		updateDirtyPreset(true);
