@@ -1,7 +1,7 @@
 // drumkv1widget_elements.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -23,20 +23,86 @@
 #define __drumkv1widget_elements_h
 
 #include <QTreeView>
+#include <QAbstractItemModel>
 
 
 // Forwards.
-class drumkv1widget_elements_model;
-
 class drumkv1_ui;
 
+class drumkv1_element;
 class drumkv1_sample;
 
+class QPixmap;
+
 class QDragEnterEvent;
 class QDragMoveEvent;
 class QDropEvent;
 
 
+//----------------------------------------------------------------------------
+// drumkv1widget_elements_model -- List model.
+
+class drumkv1widget_elements_model : public QAbstractItemModel
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	drumkv1widget_elements_model(drumkv1_ui *pDrumkUi, QObject *pParent = NULL);
+
+	// Destructor.
+	~drumkv1widget_elements_model();
+
+	// Concretizers (virtual).
+	int rowCount(const QModelIndex& parent = QModelIndex()) const;
+	int columnCount(const QModelIndex& parent = QModelIndex()) const;
+
+	QVariant headerData(int section, Qt::Orientation orient, int role) const;
+	QVariant data(const QModelIndex& index, int role) const;
+
+	QModelIndex index(int row, int column,
+		const QModelIndex& parent = QModelIndex()) const;
+
+	QModelIndex parent(const QModelIndex&) const;
+
+	void reset();
+
+	// Accessor specific.
+	drumkv1_ui *instance() const;
+
+	void midiInLedNote(int key, int vel);
+
+protected slots:
+
+	void midiInLedTimeout();
+
+protected:
+
+	// Other specifics
+	drumkv1_element *elementFromIndex(const QModelIndex& index) const;
+
+	QString itemDisplay(const QModelIndex& index) const;
+	QString itemToolTip(const QModelIndex& index) const;
+
+	int columnAlignment(int column) const;
+
+	void midiInLedUpdate(int key);
+
+private:
+
+	// Model variables.
+	QPixmap    *m_pixmaps[2];
+	QStringList m_headers;
+
+	drumkv1_ui *m_pDrumkUi;
+
+	static const int MAX_NOTES = 128;
+	int m_notes_on[MAX_NOTES];
+	QList<int> m_notes_off;
+};
+
+
 //----------------------------------------------------------------------------
 // drumkv1widget_elements -- Custom (tree) list view.
 
@@ -63,6 +129,12 @@ public:
 	// Refreshener.
 	void refresh();
 
+	// MIDI input status update
+	void midiInLedNote(int key, int vel);
+
+	// Direct note-on methods.
+	void directNoteOn(int key);
+
 signals:
 
 	// Emitted signals.
@@ -78,6 +150,9 @@ protected slots:
 	void currentRowChanged(const QModelIndex&, const QModelIndex&);
 	void doubleClicked(const QModelIndex&);
 
+	// Direct note-off/timeout methods.
+	void directNoteOff();
+
 protected:
 
 	// Mouse interaction.
@@ -107,6 +182,8 @@ private:
 	QPoint m_posDrag;
 
 	drumkv1_sample *m_pDragSample;
+
+	int m_iDirectNoteOn;
 };
 
 
