@@ -1,7 +1,7 @@
 // drumkv1widget_sample.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -91,9 +91,6 @@ void drumkv1widget_sample::setSample ( drumkv1_sample *pSample )
 
 	m_pSample = pSample;
 
-//	m_bLoop = false;
-//	m_iLoopStart = m_iLoopEnd = 0;
-
 	m_pDragSample = NULL;
 
 	if (m_pSample)
@@ -103,7 +100,7 @@ void drumkv1widget_sample::setSample ( drumkv1_sample *pSample )
 		const int w = width() & 0x7ffe; // force even.
 		const int w2 = (w >> 1);
 		const unsigned int nframes = m_pSample->length();
-		const unsigned int nperiod = nframes / w2;
+		const float period = float(nframes) / float(w2);
 		const int h0 = h / m_iChannels;
 		const float h1 = float(h0 >> 1);
 		int y0 = h1;
@@ -115,18 +112,18 @@ void drumkv1widget_sample::setSample ( drumkv1_sample *pSample )
 			float vmin = 0.0f;
 			int n = 0;
 			int x = 1;
-			unsigned int j = nperiod;
+			unsigned int j = 0;
 			for (unsigned int i = 0; i < nframes; ++i) {
 				const float v = *pframes++;
 				if (vmax < v)
 					vmax = v;
 				if (vmin > v)
 					vmin = v;
-				if (++j > nperiod) {
+				if (i > j) {
 					m_ppPolyg[k]->setPoint(n, x, y0 - int(vmax * h1));
 					m_ppPolyg[k]->setPoint(w - n - 1, x, y0 - int(vmin * h1));
-					j = 0; vmax = vmin = 0.0f;
-					++n; x += 2;
+					vmax = vmin = 0.0f;
+					++n; x += 2; j = (unsigned int) (float(n) * period);
 				}
 			}
 			while (n < w2) {
@@ -486,11 +483,6 @@ void drumkv1widget_sample::paintEvent ( QPaintEvent *pPaintEvent )
 
     painter.fillRect(rect, rgbDark);
 
-	if (!m_sName.isEmpty()) {
-		painter.setPen(pal.midlight().color());
-		painter.drawText(rect.adjusted(2, 0, -2, -0), Qt::AlignLeft, m_sName);
-	}
-
 	if (m_pSample && m_ppPolyg) {
 		const int w2 = (w << 1);
 		painter.setRenderHint(QPainter::Antialiasing, true);
@@ -529,6 +521,22 @@ void drumkv1widget_sample::paintEvent ( QPaintEvent *pPaintEvent )
 			tr("(double-click or drop to load new sample...)"));
 	}
 
+	QString sTitle = m_sName;
+	if (m_pSample && m_pSample->filename()) {
+		if (!sTitle.isEmpty()) {
+			sTitle += ' ';
+			sTitle += '-';
+			sTitle += ' ';
+		}
+		sTitle += QFileInfo(
+			QString::fromUtf8(m_pSample->filename())
+		).completeBaseName();
+	}
+	if (!sTitle.isEmpty()) {
+		painter.setPen(pal.midlight().color());
+		painter.drawText(rect.adjusted(2, 0, -2, -0), Qt::AlignLeft, sTitle);
+	}
+
 	painter.end();
 
 	QFrame::paintEvent(pPaintEvent);
@@ -542,7 +550,9 @@ void drumkv1widget_sample::openSample ( const QString& sName )
 	if (pConfig == NULL)
 		return;
 
-	QString sFilename;
+	QString sFilename = pConfig->sSampleDir;
+	if (m_pSample && m_pSample->filename())
+		sFilename = QString::fromUtf8(m_pSample->filename());
 
 	// Cache supported file-types stuff from libsndfile...
 	static QStringList s_filters;
@@ -576,22 +586,23 @@ void drumkv1widget_sample::openSample ( const QString& sName )
 
 	const QString& sTitle  = tr("Open Sample [%1]").arg(sName) + " - " DRUMKV1_TITLE;
 	const QString& sFilter = s_filters.join(";;");
-#if 1//QT_VERSION < 0x040400
+	QWidget *pParentWidget = NULL;
 	QFileDialog::Options options = 0;
-	if (pConfig->bDontUseNativeDialogs)
+	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
-	sFilename = QFileDialog::getOpenFileName(parentWidget(),
-		sTitle, pConfig->sSampleDir, sFilter, NULL, options);
+		pParentWidget = parentWidget();
+	}
+#if 1//QT_VERSION < 0x040400
+	sFilename = QFileDialog::getOpenFileName(pParentWidget,
+		sTitle, sFilename, sFilter, NULL, options);
 #else
-	QFileDialog fileDialog(nativeParentWidget(),
-		sTitle, pConfig->sSampleDir, sFilter);
+	QFileDialog fileDialog(pParentWidget, sTitle, sFilename, sFilter);
 	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
 	fileDialog.setFileMode(QFileDialog::ExistingFile);
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(pConfig->sSampleDir));
 	fileDialog.setSidebarUrls(urls);
-	if (pConfig->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
 #endif
